#!/usr/bin/env python
import os
import cmdln
import riak
import ConfigParser
import pprint

HOME = os.path.expanduser("~")

# Get the configuration (assume home directory, if not, default)
config = ConfigParser.RawConfigParser()

if os.path.isfile("%s/.riakc" % HOME):
    config.read("%s/.riakc" % HOME)
else:
    config.read("%s/riakc.ini" % os.getcwd())

HOST = config.get("connection", "host")
PORT = config.get("connection", "port")

PP   = pprint.PrettyPrinter(indent=4)

client = riak.RiakClient(port=int(PORT), host=HOST, transport_class=riak.RiakPbcTransport)

class RiakcException(Exception):
    pass

if not client.is_alive():
    raise RiakcException("Riak is not responding...")

class Riakc(cmdln.Cmdln):
    """
    Basic Riak command line utility.
    """
    
    name = "riakc"
    
    def do_list(self, subcmd, opts, bucket_name=None):
        """${cmd_name}: list all of the buckets in Riak
        
        If a bucket name is provided, this command will list all of
        the keys stored in the at bucket.
        
        ${cmd_usage}
        """
        
        if bucket_name:
            bucket = client.bucket(bucket_name)
            PP.pprint(bucket.get_keys())
        else:
            PP.pprint(client.get_buckets())
    
    def do_get(self, subcmd, opts, bucket_name, key):
        """${cmd_name}: get a key's data
        
        ${cmd_usage}
        """
        
        bucket = client.bucket(bucket_name)
        item   = bucket.get(key)
        
        if item._exists:
            PP.pprint(item.get_data())
        else:
            print "Key does not exist: %s" % key

    def do_get_meta(self, subcmd, opts, bucket_name, key):
        """${cmd_name}: get a key's metadata
        
        ${cmd_usage}
        """
        
        bucket = client.bucket(bucket_name)
        item   = bucket.get(key)
        
        if item._exists:
            PP.pprint(item.get_metadata())
        else:
            print "Key does not exist: %s" % key
        
    def do_delete(self, subcmd, opts, bucket_name, key):
        """${cmd_name}: delete a key
        
        ${cmd_usage}
        """
        
        bucket = client.bucket(bucket_name)
        item   = bucket.get(key)
        
        if item._exists:
            item.delete()
        else:
            print "Key does not exist: %s" % key



import sys
from setuptools import find_packages

try:
    from setuptools import setup
    kw = {'entry_points':
          """[console_scripts]\nriakc = riakc:main\n""",
          'zip_safe': False}
except ImportError:
    from distutils.core import setup
    if sys.platform == 'win32':
        print('Note: without Setuptools installed you will have to use "python -m riakc ENV"')
        kw = {}
    else:
        kw = {'scripts': ['scripts/riakc']}

version = '0.3.6'

if not '2.5' <= sys.version < '3.0':
    raise ImportError('Python version not supported')

tests_require = ['nose']

setup(name="riakc",
      version=version,
      install_requires=['cmdln', 'protobuf', 'riak'],
      
      description="A simple riak commandline client",
      classifiers=["Intended Audience :: Developers",
                   "License :: OSI Approved :: Python Software Foundation License",
                   "Programming Language :: Python",
                   "Topic :: Software Development :: Libraries :: Python Modules",
                   ],
      author="Parnell Springmeyer",
      author_email="ixmatus@gmail.com",
      url="http://bitbucket.org/ixmatus/riakc",
      license="PSF",
      py_modules=['riakc'],
      packages=find_packages(),
      include_package_data=True,
      test_suite='nose.collector',
      tests_require=tests_require,
      **kw
      )
